==> gnome-shell-extension-manager_0.4.2.orig.tar.gz: extension-manager-0.4.2/NEWS.md <==
# NEWS

## 0.4.2

### Features & Fixes
 - Horizontal scroll fix in Upgrade Assistant
 - Pixel perfect app icon

### Translations
 - Adds Ukrainian


## 0.4.1
Minor update

### Features & Fixes

 - Official snap support
 - Improved error log generation

### Translations

 - Updates Arabic
 - Updates Simplified Chinese
 - Updates Traditional Chinese
 - Updates French
 - Updates Norwegian Bokmal
 - Updates Occitan
 - Updates Turkish
 - Updates Estonian
 - Updates Persian
 - Updates Greek
 - Updates Dutch
 - Updates Russian
 - Updates Portuguese
 - Updates Brazillian Portuguese


## 0.4.0
Major feature update to extension-manager

### Features & Fixes

 - Fully adaptive mobile-friendly user interface
 - Paginated search results
 - Upgrade Assistant for checking extension compatibility
 - Unsupported extensions are hidden by default
 - Overhauled error and crash reporting
 - Fullscreen image viewer
 - Handles new gnome-extensions:// URI scheme
 - Randomised extension suggestions
 - Performance and stability

### Translations

 - Adds Tamil
 - Adds Estonian
 - Updates Arabic
 - Updates French
 - Updates Traditional Chinese
 - Updates Greek
 - Updates Persian
 - Updates Spanish
 - Update Italian

## 0.3.2
Minor update

 - Fix double slashes in extension urls
 - Make window title translatable
 - Miscellaneous translation fixes

### Translations
 - Adds Arabic
 - Adds Greek
 - Adds Portuguese
 - Adds Taiwanese Chinese
 - Updates Brazilian Portuguese
 - Updates Hungarian
 - Updates Russian
 - Updates Turkish

## 0.3.1
Minor update

 - Remove release notes dialog
 - Fix special characters in installed extension listings
 - Use metainfo instead of appdata
 - Set window title

### Translations
 - Adds Croatian
 - Adds Danish
 - Adds Persian
 - Adds Swedish
 - Updates Brazilian Portuguese
 - Updates Dutch
 - Updates French
 - Updates German
 - Updates Hungarian
 - Updates Occitan
 - Updates Polish
 - Updates Russian

## 0.3.0
Second feature update to extension-manager

### General

 - Add new app icon

### Features

 - In-app updates
 - Display comments and reviews
 - Display extension errors to user
 - Handle 'out of date' extensions
 - In-app release notes on first run
 - Allow installing unsupported extensions
 - Option to sort extensions by enabled status
 - Focus search entry on first open

### Maintenance

 - Added text-engine as a dependency for displaying markup
 - Add badges for build, version, license, downloads to readme file
 - Use latest meson features
 - Run appstream validate test without network

### Translations

 - Adds context to various translation strings
 - Adds Norwegian Nynorsk
 - Adds Indonesian
 - Adds Occitan
 - Updates Spanish
 - Updates Italian

## 0.2.3
Minor update

 - Various translation updates

## 0.2.2
Minor update

 - Various translation updates
 - Fix special characters in search results

## 0.2.1
Hotfix update

 - Fixes crash when uninstalling extension
 - Makes details-view more robust

## 0.2.0
First feature update to extension-manager

### General
 - Support for i18n and translations

### GUI
 - Dark Theme
 - Allow overriding system theme
 - Add new details view for online extensions
 - Display screenshots in extension listings
 - Show supported shell versions

### Local Management
 - Display system and user extensions separately
 - Sort alphabetically
 - Global extension toggle
 - Link to new details page

### Browsing
 - Avoid searching on start-up
 - Add progress indicator
 - Sort search results
 - Handle no results found

### Internal Changes
 - Restructure of directory layout
 - Use gdbus-codegen for dbus interface
 - Selectively update rows rather than recreating model
 - Rewrite GUI using Blueprint and MVC pattern
 - Use debug output and reduce logging
 - Performance and stability
 - Enforce shell version compatibility

### Translations:
 - German
 - Spanish
 - Italian
 - Japanese
 - Dutch
 - Polish
 - Brazilian Portuguese

## 0.1.0
Initial release of extension-manager

==> gnome-shell-extension-manager_0.4.3.orig.tar.gz: extension-manager-0.4.3/NEWS.md <==
# NEWS

## 0.4.3

### Features & Fixes
 - Fix sorting by recent
 - Fix sorting by relevance
 - Remove broken popularity sort
 - Add support for WebP screenshots
 - Display extension homepage
 - Fix bug with global state toggle
 - Fix margins in local extensions list
 - Improved keyboard navigation
 - Remove app theme selector and use system settings
 - Uses new libadwaita widgets under the hood

### Translations
 - Updates Czech
 - Updates French
 - Updates German
 - Updates Russian
 - Updates Spanish
 - Updates Tamil
 - Updates Ukrainian

## 0.4.2

### Features & Fixes
 - Horizontal scroll fix in Upgrade Assistant
 - Pixel perfect app icon

### Translations
 - Adds Ukrainian


## 0.4.1
Minor update

### Features & Fixes

 - Official snap support
 - Improved error log generation

### Translations

 - Updates Arabic
 - Updates Simplified Chinese
 - Updates Traditional Chinese
 - Updates French
 - Updates Norwegian Bokmal
 - Updates Occitan
 - Updates Turkish
 - Updates Estonian
 - Updates Persian
 - Updates Greek
 - Updates Dutch
 - Updates Russian
 - Updates Portuguese
 - Updates Brazillian Portuguese


## 0.4.0
Major feature update to extension-manager

### Features & Fixes

 - Fully adaptive mobile-friendly user interface
 - Paginated search results
 - Upgrade Assistant for checking extension compatibility
 - Unsupported extensions are hidden by default
 - Overhauled error and crash reporting
 - Fullscreen image viewer
 - Handles new gnome-extensions:// URI scheme
 - Randomised extension suggestions
 - Performance and stability

### Translations

 - Adds Tamil
 - Adds Estonian
 - Updates Arabic
 - Updates French
 - Updates Traditional Chinese
 - Updates Greek
 - Updates Persian
 - Updates Spanish
 - Update Italian

## 0.3.2
Minor update

 - Fix double slashes in extension urls
 - Make window title translatable
 - Miscellaneous translation fixes

### Translations
 - Adds Arabic
 - Adds Greek
 - Adds Portuguese
 - Adds Taiwanese Chinese
 - Updates Brazilian Portuguese
 - Updates Hungarian
 - Updates Russian
 - Updates Turkish

## 0.3.1
Minor update

 - Remove release notes dialog
 - Fix special characters in installed extension listings
 - Use metainfo instead of appdata
 - Set window title

### Translations
 - Adds Croatian
 - Adds Danish
 - Adds Persian
 - Adds Swedish
 - Updates Brazilian Portuguese
 - Updates Dutch
 - Updates French
 - Updates German
 - Updates Hungarian
 - Updates Occitan
 - Updates Polish
 - Updates Russian

## 0.3.0
Second feature update to extension-manager

### General

 - Add new app icon

### Features

 - In-app updates
 - Display comments and reviews
 - Display extension errors to user
 - Handle 'out of date' extensions
 - In-app release notes on first run
 - Allow installing unsupported extensions
 - Option to sort extensions by enabled status
 - Focus search entry on first open

### Maintenance

 - Added text-engine as a dependency for displaying markup
 - Add badges for build, version, license, downloads to readme file
 - Use latest meson features
 - Run appstream validate test without network

### Translations

 - Adds context to various translation strings
 - Adds Norwegian Nynorsk
 - Adds Indonesian
 - Adds Occitan
 - Updates Spanish
 - Updates Italian

## 0.2.3
Minor update

 - Various translation updates

## 0.2.2
Minor update

 - Various translation updates
 - Fix special characters in search results

## 0.2.1
Hotfix update

 - Fixes crash when uninstalling extension
 - Makes details-view more robust

## 0.2.0
First feature update to extension-manager

### General
 - Support for i18n and translations

### GUI
 - Dark Theme
 - Allow overriding system theme
 - Add new details view for online extensions
 - Display screenshots in extension listings
 - Show supported shell versions

### Local Management
 - Display system and user extensions separately
 - Sort alphabetically
 - Global extension toggle
 - Link to new details page

### Browsing
 - Avoid searching on start-up
 - Add progress indicator
 - Sort search results
 - Handle no results found

### Internal Changes
 - Restructure of directory layout
 - Use gdbus-codegen for dbus interface
 - Selectively update rows rather than recreating model
 - Rewrite GUI using Blueprint and MVC pattern
 - Use debug output and reduce logging
 - Performance and stability
 - Enforce shell version compatibility

### Translations:
 - German
 - Spanish
 - Italian
 - Japanese
 - Dutch
 - Polish
 - Brazilian Portuguese

## 0.1.0
Initial release of extension-manager
